@@ -70,6 +70,9 @@ class ReflectModel(object):
         self.threads = threads
         self.quad_order = quad_order
 
+        # to make it more like a refnx.analysis.Model
+        self.fitfunc = None
+
         # all reflectometry models need a scale factor and background
         self._scale = possibly_create_parameter(scale, name='scale')
         self._bkg = possibly_create_parameter(bkg, name='bkg')
@@ -179,7 +182,7 @@ class ReflectModel(object):
                             threads=self.threads,
                             quad_order=self.quad_order)
 
-    def lnprob(self):
+    def logp(self):
         r"""
         Additional log-probability terms for the reflectivity model. Do not
         include log-probability terms for model parameters, these are
@@ -187,11 +190,11 @@ class ReflectModel(object):
 
         Returns
         -------
-        lnprob : float
+        logp : float
             log-probability of structure.
 
         """
-        return self.structure.lnprob()
+        return self.structure.logp()
 
     @property
     def structure(self):
@@ -223,7 +226,7 @@ class ReflectModel(object):
 
 
 def reflectivity(q, slabs, scale=1., bkg=0., dq=5., quad_order=17,
-                 threads=0):
+                 threads=-1):
     r"""
     Abeles matrix formalism for calculating reflectivity from a stratified
     medium.
@@ -300,7 +303,7 @@ def reflectivity(q, slabs, scale=1., bkg=0., dq=5., quad_order=17,
         Specifies the number of threads for parallel calculation. This
         option is only applicable if you are using the ``_creflect``
         module. The option is ignored if using the pure python calculator,
-        ``_reflect``. If `threads == 0` then all available processors are
+        ``_reflect``. If `threads == -1` then all available processors are
         used.
 
     Example
@@ -433,7 +436,7 @@ def _smearkernel(x, w, q, dq, threads):
     return refcalc.abeles(localq, w, threads=threads) * gauss
 
 
-def _smeared_abeles_adaptive(qvals, w, dqvals, threads=0):
+def _smeared_abeles_adaptive(qvals, w, dqvals, threads=-1):
     """
     Resolution smearing that uses adaptive Gaussian quadrature integration
     for the convolution.
@@ -451,6 +454,7 @@ def _smeared_abeles_adaptive(qvals, w, dqvals, threads=0):
         Do you want to calculate in parallel? This option is only applicable if
         you are using the ``_creflect`` module. The option is ignored if using
         the pure python calculator, ``_reflect``.
+
     Returns
     -------
     reflectivity : np.ndarray
@@ -475,7 +479,7 @@ def _smeared_abeles_adaptive(qvals, w, dqvals, threads=0):
     return smeared_rvals
 
 
-def _smeared_abeles_fixed(qvals, w, dqvals, quad_order=17, threads=0):
+def _smeared_abeles_fixed(qvals, w, dqvals, quad_order=17, threads=-1):
     """
     Resolution smearing that uses fixed order Gaussian quadrature integration
     for the convolution.
@@ -496,7 +500,7 @@ def _smeared_abeles_fixed(qvals, w, dqvals, quad_order=17, threads=0):
         Specifies the number of threads for parallel calculation. This
         option is only applicable if you are using the ``_creflect``
         module. The option is ignored if using the pure python calculator,
-        ``_reflect``. If `threads == 0` then all available processors are
+        ``_reflect``. If `threads == -1` then all available processors are
         used.
 
     Returns
@@ -540,7 +544,7 @@ def _smeared_abeles_fixed(qvals, w, dqvals, quad_order=17, threads=0):
     return np.sum(smeared_rvals, 1) * _INTLIMIT
 
 
-def _smeared_abeles_constant(q, w, resolution, threads=True):
+def _smeared_abeles_constant(q, w, resolution, threads=-1):
     """
     Fast resolution smearing for constant dQ/Q.
 
@@ -636,7 +640,7 @@ class MixedReflectModel(object):
         Specifies the number of threads for parallel calculation. This
         option is only applicable if you are using the ``_creflect``
         module. The option is ignored if using the pure python calculator,
-        ``_reflect``. If `threads == 0` then all available processors are
+        ``_reflect``. If `threads == -1` then all available processors are
         used.
     quad_order: int, optional
         the order of the Gaussian quadrature polynomial for doing the
@@ -650,7 +654,7 @@ class MixedReflectModel(object):
 
     """
     def __init__(self, structures, scales=None, bkg=1e-7, name='', dq=5.,
-                 threads=0, quad_order=17):
+                 threads=-1, quad_order=17):
         self.name = name
         self._parameters = None
         self.threads = threads
@@ -781,7 +785,7 @@ class MixedReflectModel(object):
 
         return y + self.bkg.value
 
-    def lnprob(self):
+    def logp(self):
         r"""
         Additional log-probability terms for the reflectivity model. Do not
         include log-probability terms for model parameters, these are
@@ -789,15 +793,15 @@ class MixedReflectModel(object):
 
         Returns
         -------
-        lnprob : float
+        logp : float
             log-probability of structure.
 
         """
-        lnprob = 0
+        logp = 0
         for structure in self._structures:
-            lnprob += structure.lnprob()
+            logp += structure.logp()
 
-        return lnprob
+        return logp
 
     @property
     def structures(self):
